# bcond_with    = disable
# bcond_without = enable
%bcond_with    doc
%bcond_without tests
# Separate themes package
%bcond_without themes
%bcond_without xcb
%bcond_without wayland

# The naming scheme in non-Mandriva-based distros
%if 0%{!?mklibname:1}
%define mklibname(ds)  lib%{1}%{?2:%{2}}%{-s:-static}%{-d:-devel}
%endif
%if 0%{!?mkrel:1}
%define mkrel(c) %{1}%{?dist}
%endif

Name:    rofi
Version: 1.7.9+wayland1
Release: %mkrel 1
Summary: A window switcher, application launcher and dmenu replacement

# lexer/theme-parser.[ch]:
# These files are generated from lexer/theme-parser.y and licensed with GPLv3+
# with Bison exception.
# As the source file is licensed with MIT, according to the Bison exception,
# the shipped files are considered to be MIT-licensed.
# See also
# https://lists.fedoraproject.org/archives/list/legal@lists.fedoraproject.org/message/C4VVT54Z4WFGJPPD5X54ILKRF6X2IFLZ/
License: MIT
URL:     https://github.com/lbonn/%{name}
Source: https://github.com/lbonn/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz

# Basic build system
BuildRequires: pkgconfig
BuildRequires: gcc-c++
BuildRequires: bison
BuildRequires: flex
BuildRequires: meson >= 0.59.0
BuildRequires: ninja
# Documentation
%if %{with doc}
BuildRequires: doxygen
BuildRequires: graphviz
%endif
# Plugins
BuildRequires: pkgconfig(glib-2.0)
BuildRequires: pkgconfig(gmodule-2.0)
BuildRequires: pkgconfig(cairo)
# Base dependencies
BuildRequires: pkgconfig(gio-unix-2.0)
BuildRequires: pkgconfig(pango)
BuildRequires: pkgconfig(pangocairo)
BuildRequires: pkgconfig(xkbcommon)
BuildRequires: pkgconfig(gdk-pixbuf-2.0)
# XCB dependencies
%if %{with xcb}
BuildRequires: pkgconfig(xcb)
BuildRequires: pkgconfig(xcb-aux)
BuildRequires: pkgconfig(cairo-xcb)
BuildRequires: pkgconfig(libstartup-notification-1.0)
BuildRequires: pkgconfig(xcb-cursor)
BuildRequires: pkgconfig(xcb-ewmh)
BuildRequires: pkgconfig(xcb-icccm)
BuildRequires: pkgconfig(xcb-randr)
BuildRequires: pkgconfig(xcb-xinerama)
BuildRequires: pkgconfig(xcb-xkb)
BuildRequires: pkgconfig(xcb-keysyms)
BuildRequires: pkgconfig(xkbcommon-x11)
%endif
# Wayland dependencies
%if %{with wayland}
BuildRequires: pkgconfig(wayland-protocols)
BuildRequires: pkgconfig(wayland-client)
BuildRequires: pkgconfig(wayland-cursor)
BuildRequires: pkgconfig(wayland-server)
BuildRequires: pkgconfig(gtk-layer-shell-0)
BuildRequires: pkgconfig(libjpeg)
BuildRequires: pkgconfig(librsvg-2.0)
%endif
# Tests
%if %{with tests}
BuildRequires: desktop-file-utils
BuildRequires: pkgconfig(check) >= 0.11.0
%endif

Provides: rofi-launcher
%if %{with wayland}
Provides: rofi-wayland = %{version}-%{release}
%endif
# https://github.com/sardemff7/libgwater
Provides: bundled(libgwater)
# https://github.com/sardemff7/libnkutils
Provides: bundled(libnkutils)

# Only needed when the package is called rofi-wayland
#Conflicts: rofi

%if %{with themes}
Requires:      %{name}-themes = %{version}-%{release}
%endif
Requires:      hicolor-icon-theme


%description
Rofi is a dmenu replacement. Rofi, like dmenu, will provide the user with a
textual list of options where one or more can be selected. This can either be,
running an application, selecting a window or options provided by an external
script.

This is a fork of rofi with added support for Wayland via the layer shell protocol.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       pkgconfig

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%if %{with doc}
%package        devel-doc
Summary:        Documentation files for %{name}
BuildArch:      noarch

%description    devel-doc
The %{name}-devel-doc package contains documentation files for developing
applications that use %{name}.
%endif

%if %{with themes}
%package        themes
Summary:        Themes for %{name}
BuildArch:      noarch

%description    themes
The %{name}-themes package contains themes for %{name}.
%endif


%prep
%autosetup -n rofi-%{version}

sed -i '1s,%{_bindir}/env bash,/bin/sh,' script/rofi-sensible-terminal \
    script/rofi-theme-selector
%build

pkg-config --exists check && with_check=enabled || with_check=disabled
pkg-config --exists wayland-protocols wayland-client wayland-cursor wayland-server gtk-layer-shell-0 && with_wayland=enabled || with_wayland=disabled
pkg-config --exists xcb xcb-aux cairo-xcb libstartup-notification-1.0 xcb-cursor xcb-ewmh xcb-icccm xcb-randr xcb-xinerama xcb-xkb xkbcommon-x11 && with_xcb=enabled || with_xcb=disabled

%meson \
	-Ddrun=true \
	-Dwindow=true \
        -Dcheck=$with_check \
        -Dwayland=$with_wayland \
        -Dxcb=$with_xcb \
	-Dimdkit=false
%meson_build
%if %{with doc}
ninja -C build doc/html
find build/doc/html/html -name "*.md5" -exec rm -f '{}' \;
rm -fr build/doc/html/xml
%endif


%install
%meson_install \

%if %{with tests}
%check
desktop-file-validate %{buildroot}%{_datadir}/applications/rofi*.desktop
%endif


%files
%doc README.md
%license COPYING
%{_bindir}/rofi
%{_bindir}/rofi-sensible-terminal
%{_bindir}/rofi-theme-selector
%{_datadir}/applications/rofi.desktop
%{_datadir}/applications/rofi-theme-selector.desktop
%{_datadir}/icons/hicolor/scalable/apps/rofi.svg
%if !%{with themes}
%{_datadir}/rofi/themes/
%endif
%{_mandir}/man1/rofi*
%{_mandir}/man5/rofi*

%if %{with themes}
%files themes
%license COPYING
%{_datarootdir}/rofi
%endif

%files devel
%{_includedir}/rofi
%{_libdir}/pkgconfig/rofi.pc

%if %{with doc}
%files devel-doc
%license COPYING
%doc doc/html/html/*
%endif



%changelog
* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.7.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.7.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Sun Aug 21 2022 Anthony Rabbito <hello@anthonyrabbito.com> - 1.7.5-1
- Update to 1.7.5 (#2119919)
  update owner in URL

* Mon Aug 15 2022 Aleksei Bavshin <alebastr@fedoraproject.org> - 1.7.4-1
- Update to 1.7.4 (#2118201)

* Sat Jul 23 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.7.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Sat Feb 05 2022 Aleksei Bavshin <alebastr@fedoraproject.org> - 1.7.3-1
- Update to 1.7.3 (#2048137)

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.7.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Tue Nov 30 2021 Aleksei Bavshin <alebastr@fedoraproject.org> - 1.7.2-1
- Update to 1.7.2 (#2027032)

* Mon Sep 06 2021 Aleksei Bavshin <alebastr@fedoraproject.org> - 1.7.0-1
- Update to 1.7.0

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Thu Dec  3 2020 Dan Čermák <dan.cermak@cgc-instruments.com> - 1.6.1-1
- New upstream release 1.6.1 (rhbz#1900420)

* Sun Sep 13 2020 Dan Čermák <dan.cermak@cgc-instruments.com> - 1.6.0-1
- New upstream release (rhbz#1876283)

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.5.4-4
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.5.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.5.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Aug 01 2019 Till Hofmann <thofmann@fedoraproject.org> - 1.5.4-1
- Update to 1.5.4

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.5.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Jun 21 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 1.5.2-1
- Update to 1.5.2

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.5.1-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Tue Nov 13 2018 Till Hofmann <hofmann@kbsg.rwth-aachen.de> - 1.5.1-7
- Add patch to fix undefined behavior of char* initialization

* Sun Nov 11 2018 Till Hofmann <thofmann@fedoraproject.org> - 1.5.1-6
- Do not package .md5 or .map files
- Remove scriptlet to modify shebang, rely on mangler instead

* Sat Nov 10 2018 Till Hofmann <thofmann@fedoraproject.org> - 1.5.1-5
- Replace BR pkconfig(xcb-util) -> pkgconfig(xcb-aux)
- Clarify license of bison-generated files

* Thu Nov 08 2018 Till Hofmann <thofmann@fedoraproject.org> - 1.5.1-4
- Rename doc sub-package to devel-doc

* Tue Nov 06 2018 Till Hofmann <thofmann@fedoraproject.org> - 1.5.1-3
- Install license file to all independently installable packages

* Tue Nov 06 2018 Till Hofmann <thofmann@fedoraproject.org> - 1.5.1-2
- Move themes into a separate noarch sub-package
- Make doc sub-package noarch

* Mon Nov 05 2018 Till Hofmann <thofmann@fedoraproject.org> - 1.5.1-1
- Update to 1.5.1
- Run tests
- Remove upstreamed patch
- Add missing BR: doxygen
- Add missing BR: graphviz

* Tue Oct 24 2017 Till Hofmann <thofmann@fedoraproject.org> - 1.4.2-1
- Initial package
